@@ -20,10 +20,11 @@ if (!isset($session) || !$session->isValid('saml2') ) {
 $attributes = $session->getAttributes();
 $data = '';
 foreach ($attributes as $key => $values) {
-    $data .= ($data ? '#' : '').$key.'='.join(',', $values);
+    $data .= ($data ? '#' : '').strtolower($key).'='.join(',', $values);
 }
 
-$_SERVER['REMOTE_USER'] = $attributes['seciosssystemid'][0];
+$nameid = $session->getNameID();
+$_SERVER['REMOTE_USER'] = $nameid['value'];
 $_SERVER['REMOTE_USER_DATA'] = base64_encode($data);
 
 if ($config->getValue('logout.cookies')) {
