@@ -1205,6 +1205,8 @@ sub _getAttrValues
         }
     } elsif (defined($oconf->{attr}{$attr}->{selexpr})){
         $selexpr = $oconf->{attr}{$attr}->{selexpr}[0];
+    } elsif (defined($oconf->{attr}{$attr}->{constant})) {
+        return "$attr: $oconf->{attr}{$attr}->{constant}[0]\n";
     } else {
         return '';
     }
@@ -1459,6 +1461,7 @@ sub _filter2sql
         if (!$self->_filter2sql($oconf, $args, $from, $where)) {
             return 0;
         }
+        ${$where} = "not ${$where}";
 
         return 1;
     }
@@ -1534,15 +1537,17 @@ sub _filter2sql
         if (defined($aconf->{container}) && !defined($aconf->{container}[0]->{rdn})) {
             my $paconf = $self->{object}{$aconf->{container}[0]->{oname}[0]}->{conf};
 
-            $from = "$from, $paconf->{table}[0]";
+            ${$from} = "${$from}, $paconf->{table}[0]";
             if (defined($aconf->{container}[0]->{fromtbls})) {
-                $from = "$from, $oconf->{container}[0]->{fromtbls}[0]";
+                ${$from} = "${$from}, $oconf->{container}[0]->{fromtbls}[0]";
             }
 
             if (defined($aconf->{container}[0]->{joinwhere})) {
-                $where = "$where and $aconf->{container}[0]->{joinwhere}[0]";
+                ${$where} = "${$where} and $aconf->{container}[0]->{joinwhere}[0]";
             }
         }
+    } elsif (defined($oconf->{attr}{$attr}->{constant})) {
+        ${$where} = "lower(\'$oconf->{attr}{$attr}->{constant}[0]\') $type lower(\'$value\')";
     } else {
         if (defined($oconf->{attr}{$attr}->{fromtbls})) {
             ${$from} = "${$from},$oconf->{attr}{$attr}->{fromtbls}[0]";
